@@ -2,6 +2,7 @@ from pywb.utils.statusandheaders import StatusAndHeaders
 from pywb.utils.loaders import extract_post_query, append_post_query
 
 import pprint
+import re
 
 
 #=================================================================
@@ -82,8 +83,8 @@ class WbRequest(object):
                                                  rewrite_opts)
 
             self.urlrewriter.deprefix_url()
-        else:
         # no wb_url, just store blank wb_url
+        else:
             self.wb_url = None
             self.urlrewriter = None
 
@@ -99,6 +100,9 @@ class WbRequest(object):
         # PERF
         env['X_PERF'] = {}
 
+        if env.get('HTTP_X_PYWB_NOREDIRECT'):
+            self.custom_params['noredir'] = True
+
         self._parse_extra()
 
     def _is_ajax(self):
@@ -108,6 +112,47 @@ class WbRequest(object):
 
         return False
 
+    RANGE_ARG_RX = re.compile('.*.googlevideo.com/videoplayback.*([&?]range=(\d+)-(\d+))')
+
+    RANGE_HEADER = re.compile('bytes=(\d+)-(\d+)?')
+
+    def extract_range(self):
+        url = self.wb_url.url
+        use_206 = False
+        start = None
+        end = None
+
+        range_h = self.env.get('HTTP_RANGE')
+
+        if range_h:
+            m = self.RANGE_HEADER.match(range_h)
+            if m:
+                start = m.group(1)
+                end = m.group(2)
+                use_206 = True
+
+        else:
+            m = self.RANGE_ARG_RX.match(url)
+            if m:
+                start = m.group(2)
+                end = m.group(3)
+                url = url[:m.start(1)] + url[m.end(1):]
+                use_206 = False
+
+        if not start:
+            return None
+
+        start = int(start)
+        self.custom_params['noredir'] = True
+
+        if end:
+            end = int(end)
+        else:
+            end = ''
+
+        result = (url, start, end, use_206)
+        return result
+
     def __repr__(self):
         varlist = vars(self)
         varstr = pprint.pformat(varlist)
@@ -197,5 +242,9 @@ class WbResponse(object):
 
         return self.body
 
+    def add_range(self, *args):
+        self.status_headers.add_range(*args)
+        return self
+
     def __repr__(self):
         return str(vars(self))
