@@ -50,10 +50,11 @@ class LiveRewriter(object):
 
         return (status_headers, stream)
 
-    def translate_headers(self, url, env):
+    def translate_headers(self, url, urlkey, env):
         headers = {}
 
         splits = urlsplit(url)
+        has_cookies = False
 
         for name, value in env.iteritems():
             if name == 'HTTP_HOST':
@@ -73,6 +74,11 @@ class LiveRewriter(object):
             elif name == 'HTTP_REFERER':
                 continue
 
+            elif name == 'HTTP_COOKIE':
+                name = 'Cookie'
+                value = self._req_cookie_rewrite(urlkey, value)
+                has_cookies = True
+
             elif name.startswith('HTTP_'):
                 name = name[5:].title().replace('_', '-')
 
@@ -87,9 +93,28 @@ class LiveRewriter(object):
             if value:
                 headers[name] = value
 
+        if not has_cookies:
+            value = self._req_cookie_rewrite(urlkey, '')
+            if value:
+                headers['Cookie'] = value
+
         return headers
 
+    def _req_cookie_rewrite(self, urlkey, value):
+        rule = self.rewriter.ruleset.get_first_match(urlkey)
+        if not rule or not rule.req_cookie_rewrite:
+            return value
+
+        for cr in rule.req_cookie_rewrite:
+            try:
+                value = cr['rx'].sub(cr['replace'], value)
+            except KeyError:
+                pass
+
+        return value
+
     def fetch_http(self, url,
+                   urlkey=None,
                    env=None,
                    req_headers=None,
                    follow_redirects=False,
@@ -109,7 +134,7 @@ class LiveRewriter(object):
             method = env['REQUEST_METHOD'].upper()
             input_ = env['wsgi.input']
 
-            req_headers.update(self.translate_headers(url, env))
+            req_headers.update(self.translate_headers(url, urlkey, env))
 
             if method in ('POST', 'PUT'):
                 len_ = env.get('CONTENT_LENGTH')
@@ -155,17 +180,18 @@ class LiveRewriter(object):
         if url.startswith('//'):
             url = 'http:' + url
 
+        # explicit urlkey may be passed in (say for testing)
+        if not urlkey:
+            urlkey = canonicalize(url)
+
         if is_http(url):
-            (status_headers, stream) = self.fetch_http(url, env, req_headers,
+            (status_headers, stream) = self.fetch_http(url, urlkey, env,
+                                                       req_headers,
                                                        follow_redirects,
                                                        ignore_proxies)
         else:
             (status_headers, stream) = self.fetch_local_file(url)
 
-        # explicit urlkey may be passed in (say for testing)
-        if not urlkey:
-            urlkey = canonicalize(url)
-
         if timestamp is None:
             timestamp = datetime_to_timestamp(datetime.datetime.utcnow())
 
