@@ -35,13 +35,13 @@ class UrlRewriter(object):
             return url
 
         if (self.prefix and
-            self.prefix != '/' and
-            url.startswith(self.prefix)):
+             self.prefix != '/' and
+             url.startswith(self.prefix)):
             return url
 
         if (self.full_prefix and
-            self.full_prefix != self.prefix and
-            url.startswith(self.full_prefix)):
+             self.full_prefix != self.prefix and
+             url.startswith(self.full_prefix)):
             return url
 
         wburl = self.wburl
@@ -141,11 +141,7 @@ class HttpsUrlRewriter(UrlRewriter):
     HTTPS = 'https://'
 
     def rewrite(self, url, mod=None):
-        if url.startswith(self.HTTPS):
-            result = self.HTTP + url[len(self.HTTPS):]
-            return result
-        else:
-            return url
+        return self.remove_https(url)
 
     def get_new_url(self, **kwargs):
         return kwargs.get('url')
@@ -158,3 +154,12 @@ class HttpsUrlRewriter(UrlRewriter):
 
     def deprefix_url(self):
         return self.wburl.url
+
+    @staticmethod
+    def remove_https(url):
+        rw = HttpsUrlRewriter
+        if url.startswith(rw.HTTPS):
+            result = rw.HTTP + url[len(rw.HTTPS):]
+            return result
+        else:
+            return url
