@@ -35,10 +35,14 @@ function init_banner() {
         bid = PLAIN_BANNER_ID;
     }
 
+    if (!document || !document.body) {
+        return;
+    }
+
     if (document.getElementById(bid) != null) {
         return;
     }
-    
+
     _wb_js.create_banner_element(bid);
 }
 
@@ -56,14 +60,14 @@ this.ts_to_date = function(ts, is_gmt)
     if (ts.length < 14) {
         return ts;
     }
-    
-    var datestr = (ts.substring(0, 4) + "-" + 
+
+    var datestr = (ts.substring(0, 4) + "-" +
                   ts.substring(4, 6) + "-" +
                   ts.substring(6, 8) + "T" +
                   ts.substring(8, 10) + ":" +
                   ts.substring(10, 12) + ":" +
                   ts.substring(12, 14) + "-00:00");
-    
+
     var date = new Date(datestr);
     if (is_gmt) {
         return date.toGMTString();
@@ -117,10 +121,21 @@ function notify_top() {
 }
 
 this.load = function() {
+    if (window._wb_js_inited) {
+        return;
+    }
+
+    window._wb_js_inited = true;
+
     if ((window.self == window.top) && wbinfo) {
-        if (wbinfo.top_url && (window.location.href != wbinfo.top_url) && wbinfo.mod != "bn_") {
+
+        var hash = window.location.hash;
+
+        var loc = window.location.href.replace(window.location.hash, "");
+
+        if (wbinfo.top_url && (loc != wbinfo.top_url) && wbinfo.mod != "bn_") {
             // Auto-redirect to top frame
-            window.location.replace(wbinfo.top_url);
+            window.location.replace(wbinfo.top_url + hash);
         } else {
             // Init Banner (no frame or top frame)
             add_event("readystatechange", init_banner, document);
