@@ -64,8 +64,8 @@ class SearchPageWbUrlHandler(WbUrlHandler):
         # render top level frame if in frame mode
         # (not supported in proxy mode)
         if (self.is_frame_mode and wbrequest.wb_url and
-            not wbrequest.wb_url.is_query() and
-            not wbrequest.options['is_proxy']):
+             not wbrequest.wb_url.is_query() and
+             not wbrequest.options['is_proxy']):
 
             if wbrequest.wb_url.is_top_frame:
                 return self.get_top_frame_response(wbrequest)
@@ -153,8 +153,8 @@ class WBHandler(SearchPageWbUrlHandler):
 
     def handle_not_found(self, wbrequest, nfe):
         if (not self.fallback_handler or
-            wbrequest.wb_url.is_query() or
-            wbrequest.wb_url.is_identity):
+             wbrequest.wb_url.is_query() or
+             wbrequest.wb_url.is_identity):
             raise
 
         return self.fallback_handler(wbrequest)
@@ -199,7 +199,7 @@ class StaticHandler(BaseHandler):
             if guessed[0]:
                 content_type = guessed[0]
 
-            return WbResponse.text_stream(data,
+            return WbResponse.text_stream(reader,
                                           content_type=content_type,
                                           headers=headers)
 
