@@ -15,6 +15,8 @@ from pywb.warc.recordloader import ArchiveLoadFailed
 from views import J2TemplateView, add_env_globals
 from views import J2HtmlCapturesView, HeadInsertView
 
+from rangecache import range_cache
+
 
 #=================================================================
 class CaptureException(WbException):
@@ -49,6 +51,8 @@ class ReplayView(object):
         else:
             self.response_class = WbResponse
 
+        self.enable_range_cache = config.get('enable_ranges', True)
+
         self._reporter = config.get('reporter')
 
     def render_content(self, wbrequest, cdx_lines, cdx_loader):
@@ -77,10 +81,10 @@ class ReplayView(object):
 
                     first = False
 
-                response = self.replay_capture(wbrequest,
-                                               cdx,
-                                               cdx_loader,
-                                               failed_files)
+                response = self.cached_replay_capture(wbrequest,
+                                                      cdx,
+                                                      cdx_loader,
+                                                      failed_files)
 
             except (CaptureException, ArchiveLoadFailed) as ce:
                 import traceback
@@ -99,6 +103,33 @@ class ReplayView(object):
 
         raise last_e
 
+    def cached_replay_capture(self, wbrequest, cdx, cdx_loader, failed_files):
+        def get_capture():
+            return self.replay_capture(wbrequest,
+                                       cdx,
+                                       cdx_loader,
+                                       failed_files)
+
+        if not self.enable_range_cache:
+            return get_capture()
+
+        range_info = wbrequest.extract_range()
+
+        if not range_info:
+            return get_capture()
+
+        range_status, range_iter = (range_cache.
+            handle_range(wbrequest,
+                         cdx.get('digest'),
+                         get_capture,
+                         *range_info))
+
+        response = self.response_class(range_status,
+                                       range_iter,
+                                       wbrequest=wbrequest,
+                                       cdx=cdx)
+        return response
+
     def replay_capture(self, wbrequest, cdx, cdx_loader, failed_files):
         (status_headers, stream) = (self.content_loader.
                                     resolve_headers_and_payload(cdx,
@@ -182,6 +213,9 @@ class ReplayView(object):
         if wbrequest.options['is_proxy']:
             return None
 
+        if wbrequest.custom_params.get('noredir'):
+            return None
+
         redir_needed = (wbrequest.options.get('is_timegate', False))
 
         if not redir_needed and self.redir_to_exact:
@@ -190,13 +224,16 @@ class ReplayView(object):
         if not redir_needed:
             return None
 
+        if self.enable_range_cache and wbrequest.extract_range():
+            return None
+
         new_url = (wbrequest.urlrewriter.
                    get_new_url(timestamp=cdx['timestamp'],
                                url=cdx['original']))
 
         if wbrequest.method == 'POST':
-#   FF shows a confirm dialog, so can't use 307 effectively
-#            statusline = '307 Same-Method Internal Redirect'
+            #   FF shows a confirm dialog, so can't use 307 effectively
+            #   was: statusline = '307 Same-Method Internal Redirect'
             return None
         else:
             statusline = '302 Internal Redirect'
@@ -218,7 +255,7 @@ class ReplayView(object):
 
         # skip all 304s
         if (status_headers.statusline.startswith('304') and
-            not wbrequest.wb_url.is_identity):
+             not wbrequest.wb_url.is_identity):
 
             raise CaptureException('Skipping 304 Modified: ' + str(cdx))
 
